@@ -79,6 +79,7 @@ bool TextSplit::o_processCJK{true};
 int  TextSplit::o_CJKNgramLen{2};
 bool TextSplit::o_noNumbers{false};
 bool TextSplit::o_deHyphenate{false};
+// Max word size in Unicode characters
 int  TextSplit::o_maxWordLength{40};
 int  TextSplit::o_maxWordsInSpan{6};
 
@@ -259,7 +260,8 @@ int TextSplit::whatcc(unsigned int c)
     }
 }
 
-// CJK Unicode character detection. CJK text is generally indexed using an n-gram method.
+// Chinese, Japanese, Korean Unicode character ranges. CJK text is generally indexed using an n-gram
+// method.
 // Exceptions:
 //  Hangul: we can use an external text linguistic-aware segmenter.
 //  Chinese: same. Using Jieba
@@ -314,8 +316,8 @@ int TextSplit::whatcc(unsigned int c)
 #define UNICODE_IS_KATAKANA(p) false
 #endif
 
-// Hangul detection and options. If no external tagger is configured, we process HANGUL as generic
-// CJK (n-grams)
+// Hangul ranges and options. If no external tagger is configured, we process HANGUL as generic CJK
+// (n-grams): IS_HANGUL will be false and IS_CJK true.
 #define UNICODE_IN_HANGUL_RANGE(p)             \
         (((p) >= 0x1100 && (p) <= 0x11FF) ||   \
          ((p) >= 0x3130 && (p) <= 0x318F) ||   \
@@ -329,24 +331,58 @@ int TextSplit::whatcc(unsigned int c)
 #define UNICODE_IS_HANGUL(p) false
 #endif
 
-// Same for Chinese
+// Chinese ranges: everything in CJK range defined above which is not Katakana or Hangul
 #define UNICODE_IN_CHINESE_RANGE(p) \
     (UNICODE_IS_CJK(p) && !(UNICODE_IN_KATAKANA_RANGE(p) || UNICODE_IN_HANGUL_RANGE(p)))
 #ifdef CHINESE_AS_WORDS
+// If we are not using an external text splitter, IS_CJK will be true and IS_CHINESE false
 #define UNICODE_IS_CHINESE(p) (o_extchinesetagger && UNICODE_IN_CHINESE_RANGE(p))
 #else
 #define UNICODE_IS_CHINESE(p) false
 #endif
 
+// Tibetan. For now, uses n-grams. Not CJK though so handled a bit differently (because not in the
+// big CJK range)
+#define UNICODE_IN_TIBETAN_RANGE(p) \
+    ((p) > 0x0f00 && (p) <= 0x0fff)
+#define UNICODE_IS_TIBETAN(p) UNICODE_IN_TIBETAN_RANGE(p)
+
+// Thai and Lao range are contiguous
+#define UNICODE_IN_THAI_LAO_RANGE(p) \
+    ((p) > 0x0e00 && (p) <= 0x0eff)
+#define UNICODE_IS_THAI_OR_LAO(p) UNICODE_IN_THAI_LAO_RANGE(p)
+
+// Burmese
+#define UNICODE_IN_BURMESE_RANGE(p) \
+    ((p) > 0x1000 && (p) <= 0x109f)
+#define UNICODE_IS_BURMESE(p) UNICODE_IN_BURMESE_RANGE(p)
+
+// Non CJK scripts processed as ngrams
+#define UNICODE_IS_OTHER_NGRAM(p) (UNICODE_IS_TIBETAN(p) || UNICODE_IS_THAI_OR_LAO(p) || \
+                                   UNICODE_IS_BURMESE(p))
+
+// Just for testing the ngram splitter: this European reader finds it easier to look at results when
+// using a simple A-Z range.
+#define UNICODE_IN_TESTNGRAM_RANGE(p) \
+    ((p) >= 'A' && (p) <= 'B')
+#ifdef TESTING_NGRAMS
+#define UNICODE_IS_TESTNGRAM(p) UNICODE_IN_TESTNGRAM_RANGE(p)
+#else
+#define UNICODE_IS_TESTNGRAM(p) false
+#endif
+
 bool TextSplit::isSpace(int c)
 {
     return whatcc(c) == SPACE;
 }
 bool TextSplit::isCJK(int c)
 {
-    PRETEND_USE(c);
     return UNICODE_IS_CJK(c);
 }
+bool TextSplit::noStemming(int c)
+{
+    return UNICODE_IS_CJK(c) || UNICODE_IS_OTHER_NGRAM(c);
+}
 bool TextSplit::isKATAKANA(int c)
 {
     PRETEND_USE(c);
@@ -364,18 +400,21 @@ bool TextSplit::isCHINESE(int c)
 }
 bool TextSplit::isNGRAMMED(int c)
 {
-    PRETEND_USE(c);
-    return UNICODE_IS_CJK(c) && !UNICODE_IS_KATAKANA(c) && !UNICODE_IS_HANGUL(c);
+    return UNICODE_IS_OTHER_NGRAM(c) || UNICODE_IS_TESTNGRAM(c) || 
+        (UNICODE_IS_CJK(c) && !UNICODE_IS_KATAKANA(c) && !UNICODE_IS_HANGUL(c) &&
+         !UNICODE_IS_CHINESE(c));
 }
 
 
 // This is used to detect katakana/other transitions, which must trigger a word split (there is not
 // always a separator, and katakana is otherwise treated like other, in the same routine, unless CJK
 // which has its span reader causing a word break)
-enum CharSpanClass {CSC_HANGUL, CSC_CHINESE, CSC_CJK, CSC_KATAKANA, CSC_OTHER};
+enum CharSpanClass {CSC_OTHER, CSC_HANGUL, CSC_CHINESE, CSC_CJK, CSC_KATAKANA, CSC_OTHERNGRAM,
+                    CSC_TESTNGRAM};
 std::vector<CharFlags> csc_names {
     CHARFLAGENTRY(CSC_HANGUL), CHARFLAGENTRY(CSC_CHINESE), CHARFLAGENTRY(CSC_CJK),
-    CHARFLAGENTRY(CSC_KATAKANA), CHARFLAGENTRY(CSC_OTHER)};
+    CHARFLAGENTRY(CSC_KATAKANA), CHARFLAGENTRY(CSC_OTHER), CHARFLAGENTRY(CSC_OTHERNGRAM),
+    CHARFLAGENTRY(CSC_TESTNGRAM)};
 
 // Final term checkpoint: do some checking (the kind which is simpler to do here than in the main
 // loop), then send term to our client.
@@ -392,15 +431,18 @@ inline bool TextSplit::emitterm(bool isspan, const string& w, int pos, size_t bt
     PRETEND_USE(isspan);
 #endif
 
-    int l = int(w.length());
-    if (l == 0 || l > o_maxWordLength) {
-        discarded(w, pos, btstart, btend, WORD_TOO_LONG);
-        return true;
+    // If the size in bytes is > max size in unicode chars, compute the Unicode length.
+    // The bytes test saves a bit of CPU as most words will skip the unicode test.
+    // In theory we know the character size, but in practise, it was lost somewhere in the maze.
+    if (w.size() == 0 || w.size() >= (size_t)o_maxWordLength) {
+        int l = utf8len(w);
+        if (l == 0 || l > o_maxWordLength) {
+            discarded(w, pos, btstart, btend, WORD_TOO_LONG);
+            return true;
+        }
     }
-    if (l == 1) {
-        // 1 byte word: we index single ASCII letters and digits, but nothing else. We might want to
-        // turn this into a test for a single utf8 character instead ? TBD: the calling code should
-        // know the size in characters, so turning this to an Unicode test could be for free.
+    if (w.size() == 1) {
+        // 1 byte word: we index single ASCII letters and digits, but nothing else. Why?
         unsigned int c = ((unsigned int)w[0]) & 0xff;
         if (charclasses[c] != A_ULETTER && charclasses[c] != A_LLETTER && charclasses[c] != DIGIT &&
             (!(m_flags & TXTS_KEEPWILD) || charclasses[c] != WILD)  ) {
@@ -409,10 +451,10 @@ inline bool TextSplit::emitterm(bool isspan, const string& w, int pos, size_t bt
         }
     }
     // Detect doublons. Happens...?
-    if (pos != m_prevpos || l != m_prevlen) {
+    if (pos != m_prevpos || w.size() != m_prevlen) {
         bool ret = takeword(w, pos, btstart, btend);
         m_prevpos = pos;
-        m_prevlen = int(w.length());
+        m_prevlen = w.size();
         return ret;
     }
     LOGDEB2("TextSplit::emitterm:dup: [" << w << "] pos " << pos << "\n");
@@ -640,19 +682,25 @@ bool TextSplit::text_to_words(const string &in)
         // segment AND a specific processor (e.g. external Hangul word segmenter) has been
         // configured. In other words, CJK characters are processed by the generic ngram term
         // generator, except if a language-specific processor has been implemented and configured.
+        bool gospecial = true;
         if (UNICODE_IS_KATAKANA(c)) {
             csc = CSC_KATAKANA;
         } else if (UNICODE_IS_HANGUL(c)) {
             csc = CSC_HANGUL;
         } else if (UNICODE_IS_CHINESE(c)) {
             csc = CSC_CHINESE;
+        } else if (UNICODE_IS_OTHER_NGRAM(c)) {
+            csc = CSC_OTHERNGRAM;
+        } else if (UNICODE_IS_TESTNGRAM(c)) {
+            csc = CSC_TESTNGRAM;
         } else if (UNICODE_IS_CJK(c)) {
             csc = CSC_CJK;
         } else {
+            gospecial = false;
             csc = CSC_OTHER;
         }
-        if (o_processCJK && (csc == CSC_CJK || csc == CSC_HANGUL || csc == CSC_CHINESE)) {
-            // CJK character hit. Hangul and Chineseprocessing may be special.
+        if (o_processCJK && gospecial) {
+            // Using ngrams with possible exceptions for Hangul and Chinese if so configured.
 
             // Do like at EOF with the current non-cjk data.
             if (m_wordLen || m_span.length()) {
