@@ -26,6 +26,10 @@ class Utf8Iter;
 class RclConfig;
 class CNSplitter;
 
+// If this is defined, we treat upper-case ASCII with ngrams: easier for me to look at and see
+// issues as I don't read any of the actual scripts.
+//#define TESTING_NGRAMS
+
 /** 
  * Split text into words. 
  * 
@@ -118,6 +122,9 @@ public:
     /* Not split in words */
     static bool isNGRAMMED(int c);
     static bool isSpace(int c);
+    /* At the moment, this is the union of ranges which could be processed as ngrams or with a
+       dictionary-based splitter: i.e. CJK + other SE-Asian scripts */
+    static bool noStemming(int c);
     
     /** Statistics about word length (average and dispersion) can detect bad data like undecoded
      * base64 or other mis-identified pieces of data taken as text. In practise, this keeps some
@@ -175,7 +182,8 @@ private:
     static bool o_noNumbers;  // false
     static bool o_deHyphenate; // false
     static int o_CJKNgramLen; // 2
-    static int o_maxWordLength; // 40
+    // Max term size in unicode characters.
+    static int o_maxWordLength; // set to 40 in texsplit.cpp
     static int o_maxWordsInSpan; // 6
 
     int         m_flags;
@@ -203,7 +211,7 @@ private:
     // It may happen that our cleanup would result in emitting the
     // same term twice. We try to avoid this
     int           m_prevpos{-1};
-    int           m_prevlen;
+    size_t        m_prevlen;
 
 #ifdef TEXTSPLIT_STATS
     // Stats counters. These are processed in TextSplit rather than by a 
