@@ -17,29 +17,33 @@ try:
     import pyexiv2
 except:
     print("RECFILTERROR HELPERNOTFOUND python3:pyexiv2")
-    sys.exit(1);
+    sys.exit(1)
 
-khexre = re.compile(r'.*\.0[xX][0-9a-fA-F]+$')
+khexre = re.compile(r".*\.0[xX][0-9a-fA-F]+$")
 
 pyexiv2_titles = {
-    'Xmp.dc.subject',
-    'Xmp.lr.hierarchicalSubject',
-    'Xmp.MicrosoftPhoto.LastKeywordXMP',
-    }
+    "Xmp.dc.subject",
+    "Xmp.lr.hierarchicalSubject",
+    "Xmp.MicrosoftPhoto.LastKeywordXMP",
+}
 
 # Keys for which we set meta tags
 meta_pyexiv2_keys = {
-    'Xmp.dc.subject',
-    'Xmp.lr.hierarchicalSubject',
-    'Xmp.MicrosoftPhoto.LastKeywordXMP',
-    'Xmp.digiKam.TagsList',
-    'Exif.Photo.DateTimeDigitized',
-    'Exif.Photo.DateTimeOriginal',
-    'Exif.Image.DateTime',
-    }
+    "Xmp.dc.subject",
+    "Xmp.lr.hierarchicalSubject",
+    "Xmp.MicrosoftPhoto.LastKeywordXMP",
+    "Xmp.digiKam.TagsList",
+    "Exif.Photo.DateTimeDigitized",
+    "Exif.Photo.DateTimeOriginal",
+    "Exif.Image.DateTime",
+}
+
+exiv2_dates = [
+    "Exif.Photo.DateTimeOriginal",
+    "Exif.Image.DateTime",
+    "Exif.Photo.DateTimeDigitized",
+]
 
-exiv2_dates = ['Exif.Photo.DateTimeOriginal',
-               'Exif.Image.DateTime', 'Exif.Photo.DateTimeDigitized']
 
 class ImgTagExtractor(RclBaseHandler):
     def __init__(self, em):
@@ -54,10 +58,10 @@ class ImgTagExtractor(RclBaseHandler):
         mdic = {}
         for k in keys:
             # we skip numeric keys and undecoded makernote data
-            if k != 'Exif.Photo.MakerNote' and not khexre.match(k):
+            if k != "Exif.Photo.MakerNote" and not khexre.match(k):
                 mdic[k] = str(metadata[k].raw_value)
 
-        docdata = b'<html><head>\n'
+        docdata = b"<html><head>\n"
 
         ttdata = set()
         for k in pyexiv2_titles:
@@ -66,7 +70,7 @@ class ImgTagExtractor(RclBaseHandler):
         if ttdata:
             title = ""
             for v in ttdata:
-                v = v.replace('[', '').replace(']', '').replace("'", "")
+                v = v.replace("[", "").replace("]", "").replace("'", "")
                 title += v + " "
             docdata += rclexecm.makebytes("<title>" + title + "</title>\n")
 
@@ -75,26 +79,30 @@ class ImgTagExtractor(RclBaseHandler):
                 # Recoll wants: %Y-%m-%d %H:%M:%S.
                 # We get 2014:06:27 14:58:47
                 dt = mdic[k].replace(":", "-", 2)
-                docdata += b'<meta name="date" content="' + \
-                           rclexecm.makebytes(dt) + b'">\n'
+                docdata += (
+                    b'<meta name="date" content="' + rclexecm.makebytes(dt) + b'">\n'
+                )
                 break
 
-        for k,v in mdic.items():
-            if k ==  'Xmp.digiKam.TagsList':
-                docdata += b'<meta name="keywords" content="' + \
-                           rclexecm.makebytes(rclexecm.htmlescape(mdic[k])) + \
-                           b'">\n'
+        for k, v in mdic.items():
+            if k == "Xmp.digiKam.TagsList":
+                docdata += (
+                    b'<meta name="keywords" content="'
+                    + rclexecm.makebytes(rclexecm.htmlescape(mdic[k]))
+                    + b'">\n'
+                )
 
-        docdata += b'</head><body>\n'
-        for k,v in mdic.items():
-            docdata += rclexecm.makebytes(k + " : " + \
-                                     rclexecm.htmlescape(mdic[k]) + "<br />\n")
-        docdata += b'</body></html>'
+        docdata += b"</head><body>\n"
+        for k, v in mdic.items():
+            docdata += rclexecm.makebytes(
+                k + " : " + rclexecm.htmlescape(mdic[k]) + "<br />\n"
+            )
+        docdata += b"</body></html>"
 
         return docdata
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     proto = rclexecm.RclExecM()
     extract = ImgTagExtractor(proto)
     rclexecm.main(proto, extract)
