@@ -455,7 +455,7 @@ bool FsIndexer::purgeFiles(list<string>& files)
 
     for (list<string>::iterator it = files.begin(); it != files.end(); ) {
         string udi;
-        make_udi(*it, cstr_null, udi);
+        fileUdi::make_udi(*it, cstr_null, udi);
         // rcldb::purgefile returns true if the udi was either not
         // found or deleted, false only in case of actual error
         bool existed;
@@ -659,7 +659,7 @@ FsTreeWalker::Status FsIndexer::processonefile(
     string sig;
     fsmakesig(stp, sig);
     string udi;
-    make_udi(fn, cstr_null, udi);
+    fileUdi::make_udi(fn, cstr_null, udi);
     unsigned int existingDoc;
     string oldsig;
     bool needupdate;
@@ -776,7 +776,7 @@ FsTreeWalker::Status FsIndexer::processonefile(
             } else {
                 hadNonNullIpath = true;
             }
-            make_udi(fn, doc.ipath, udi);
+            fileUdi::make_udi(fn, doc.ipath, udi);
 
             // Set file name, mod time and url if not done by
             // filter. We used to set the top-level container file
@@ -789,14 +789,14 @@ FsTreeWalker::Status FsIndexer::processonefile(
 
 #ifdef EXT4_BIRTH_TIME
             if (!brdate.empty() && !doc.hasmetavalue(Rcl::Doc::keybrt) ) {
-                doc.addmeta(Rcl::Doc::keybrt, brdate);
+                doc.meta[Rcl::Doc::keybrt] = brdate;
             }
  #endif   
             if (doc.url.empty())
                 doc.url = path_pathtofileurl(fn);
 
             if (doc.ipath.empty() && !doc.hasmetavalue(Rcl::Doc::keyfn)) {
-                doc.addmeta(Rcl::Doc::keyfn, utf8fn);
+                doc.meta[Rcl::Doc::keyfn] = utf8fn;
             } 
             // Set container file name for all docs, top or subdoc
             doc.meta[Rcl::Doc::keyctfn] = utf8fn;
@@ -888,12 +888,12 @@ FsTreeWalker::Status FsIndexer::processonefile(
             map<string, string> xfields;
             reapXAttrs(config, fn, xfields);
             docFieldsFromXattrs(config, xfields, fileDoc);
-            fileDoc.onlyxattr = true;
+            fileDoc.metaonly = true;
         } else {
             fileDoc.fmtime = ascdate;
 #ifdef EXT4_BIRTH_TIME
             if (!brdate.empty()) 
-                fileDoc.addmeta(Rcl::Doc::keybrt, brdate);
+                fileDoc.meta[Rcl::Doc::keybrt] = brdate;
 #endif
             fileDoc.meta[Rcl::Doc::keyfn] = fileDoc.meta[Rcl::Doc::keyctfn] = utf8fn;
             fileDoc.haschildren = true;
