@@ -66,15 +66,14 @@ public:
     bool index(int flags);
 
     /** Index a list of files. No db cleaning or stemdb updating */
-    bool indexFiles(std::list<std::string> &files, 
-                    int f = ConfIndexer::IxFNone);
+    bool indexFiles(std::list<std::string> &files, int f = ConfIndexer::IxFNone);
 
     /** Purge a list of files. */
     bool purgeFiles(std::list<std::string> &files);
 
     /**  Tree walker callback method */
     FsTreeWalker::Status 
-    processone(const string &fn, const struct PathStat *, FsTreeWalker::CbFlag);
+    processone(const std::string &fn, FsTreeWalker::CbFlag, const struct PathStat& st) override;
 
 private:
 
@@ -85,7 +84,7 @@ private:
         void setRecord(bool onoff) {
             dorecord = onoff;
         }
-        void record(const string& udi) {
+        void record(const std::string& udi) {
             // This test does not need to be protected: the value is set at
             // init and never changed.
             if (!dorecord)
@@ -95,7 +94,7 @@ private:
 #endif
             udis.push_back(udi);
         }
-        const vector<string>& getCandidates() {
+        const std::vector<std::string>& getCandidates() {
             return udis;
         }
     private:
@@ -112,7 +111,7 @@ private:
     FsTreeWalker m_walker;
     RclConfig   *m_config;
     Rcl::Db     *m_db;
-    string       m_reason;
+    std::string       m_reason;
     // Top/start directories list
     std::vector<std::string> m_tdl;
     // Store for missing filters and associated mime types
@@ -128,8 +127,8 @@ private:
     // localfields get exactly the same processing as those generated by the
     // filters (as was done for metadatacmds fields)
     bool         m_havelocalfields;
-    string       m_slocalfields;
-    map<string, string>  m_localfields;
+    std::string       m_slocalfields;
+    std::map<std::string, std::string>  m_localfields;
 
     // Activate detection of xattr-only document updates. Experimental, so
     // needs a config option
@@ -152,12 +151,11 @@ private:
 
     bool init();
     void localfieldsfromconf();
-    void setlocalfields(const map<string, string>& flds, Rcl::Doc& doc);
-    string getDbDir() {return m_config->getDbDir();}
+    void setlocalfields(const std::map<std::string, std::string>& flds, Rcl::Doc& doc);
+    std::string getDbDir() {return m_config->getDbDir();}
     FsTreeWalker::Status 
-    processonefile(RclConfig *config, const string &fn, 
-                   const struct PathStat *,
-                   const map<string,string>& localfields);
+    processonefile(RclConfig *config, const std::string &fn, 
+                   const struct PathStat &, const std::map<std::string, std::string>& localfields);
     void shutdownQueues(bool);
 };
 
