@@ -230,6 +230,8 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
     if (bconf.ok()) {
         auto bckids = bconf.getSubKeys();
         for (const auto& bckid : bckids) {
+            if (bckid.empty())
+                continue;
             string sindex;
             if (!bconf.get("index", sindex, bckid) || sindex.empty()) {
                 LOGDEB0("ConfIndexer: no 'index' entry for [" << bckid << "]\n");
@@ -239,9 +241,9 @@ bool ConfIndexer::index(bool resetbefore, ixType typestorun, int flags)
             vector<string> vindex;
             stringToStrings(sindex, vindex);
             // We look up the command as we do for filters
-            vindex[0] = m_config->findFilter(vindex[0]);
-            if (!path_isabsolute(vindex[0])) {
-                LOGERR("ConfIndexer: "<<vindex[0] <<" not found in exec path or filters folder.\n");
+            if (!m_config->processFilterCmd(vindex)) {
+                LOGERR("ConfIndexer: command not found in exec path or filters folder: "  <<
+                       stringsToString(vindex) << "\n");
                 continue;
             }
             if (!statusUpdater()->update(DbIxStatus::DBIXS_FILES, bckid)) {
@@ -288,9 +290,12 @@ bool ConfIndexer::indexFiles(list<string>& ifiles, int flags)
     }
     myfiles.sort();
 
-    if (!m_db.open(Rcl::Db::DbUpd)) {
-        LOGERR("ConfIndexer: indexFiles error opening database " <<
-               m_config->getDbDir() << "\n");
+    Rcl::Db::OpenError error;
+    int dbflags = 0;
+    if ((flags & IxFNoTmpDb) != 0)
+        dbflags |= Rcl::Db::DbOFNoTmpDb;
+    if (!m_db.open(Rcl::Db::DbUpd, &error, dbflags)) {
+        LOGERR("ConfIndexer::indexFiles: error opening db in: " << m_config->getDbDir() << "\n");
         return false;
     }
 
@@ -340,8 +345,9 @@ bool ConfIndexer::purgeFiles(list<string> &files, int flags)
     }
     myfiles.sort();
 
-    if (!m_db.open(Rcl::Db::DbUpd)) {
-        LOGERR("ConfIndexer: purgeFiles error opening database " << m_config->getDbDir() << "\n");
+    Rcl::Db::OpenError error;
+    if (!m_db.open(Rcl::Db::DbUpd, &error, Rcl::Db::DbOFNoTmpDb)) {
+        LOGERR("ConfIndexer::purgeFiles error opening db in: " << m_config->getDbDir() << "\n");
         return false;
     }
     bool ret = false;
@@ -379,8 +385,10 @@ bool ConfIndexer::createStemmingDatabases()
     string slangs;
     bool ret = true;
     if (m_config->getConfParam("indexstemminglanguages", slangs)) {
-        if (!m_db.open(Rcl::Db::DbUpd)) {
-            LOGERR("ConfIndexer::createStemmingDb: could not open db\n");
+        Rcl::Db::OpenError error;
+        if (!m_db.open(Rcl::Db::DbUpd, &error, Rcl::Db::DbOFNoTmpDb)) {
+            LOGERR("ConfIndexer::createStemmingDatabases: error opening db in: " <<
+                   m_config->getDbDir() << "\n");
             addIdxReason("stemming", "could not open db");
             return false;
         }
@@ -406,8 +414,11 @@ bool ConfIndexer::createStemmingDatabases()
 
 bool ConfIndexer::createStemDb(const string &lang)
 {
-    if (!m_db.open(Rcl::Db::DbUpd))
+    Rcl::Db::OpenError error;
+    if (!m_db.open(Rcl::Db::DbUpd, &error, Rcl::Db::DbOFNoTmpDb)) {
+        LOGERR("ConfIndexer::createStemDb: error opening db in: " << m_config->getDbDir() << "\n");
         return false;
+    }
     vector<string> langs;
     stringToStrings(lang, langs);
     return m_db.createStemDbs(langs);
