@@ -46,7 +46,7 @@
 #include "recollindex.h"
 #include "indexer.h"
 #include "pathut.h"
-#ifndef _WIN32
+#ifndef DISABLE_X11MON
 #include "x11mon.h"
 #endif
 #include "subtreelist.h"
@@ -216,6 +216,15 @@ void RclMonEventQueue::setopts(int opts)
 {
     if (m_data)
         m_data->m_opts = opts;
+
+    // added later: why not to store m_opts in the queue class as well?
+    // it is convenient and makes RclMonEventQueue::getopt cleaner
+    m_opts = opts;
+}
+
+bool RclMonEventQueue::getopt(int mask)
+{
+    return m_opts & mask;
 }
 
 /** Wait until there is something to process on the queue, or timeout.
@@ -481,7 +490,7 @@ bool startMonitor(RclConfig *conf, int opts)
 
             // x11IsAlive() can't be called from ok() because both
             // threads call it and Xlib is not multithreaded.
-#ifndef _WIN32
+#ifndef DISABLE_X11MON
             bool x11dead = !(opts & RCLMON_NOX11) && !x11IsAlive();
             if (x11dead)
                 LOGDEB("RclMonprc: x11 is dead\n");
