@@ -20,7 +20,7 @@
 #include <stdio.h>
 #include <errno.h>
 #include <stdint.h>
-#include "safefcntl.h"
+#include <fcntl.h>
 #include <sys/types.h>
 #include "safeunistd.h"
 
@@ -73,6 +73,19 @@ static string colon_restore(const string& in)
     return out;
 }
 
+//#define DEBUGMETASTACK
+#ifdef DEBUGMETASTACK
+static void dumpmap(std::ostream& o, std::map<std::string, std::string> meta)
+{
+    for (const auto& [key, val] : meta) {
+        if (key == cstr_dj_keycontent)
+            continue;
+        o << key << " -> " << val << " | ";
+    }
+    o << "\n";
+}
+#endif // DEBUGMETASTACK
+
 // This is used when the user wants to retrieve a search result doc's parent
 // (ie message having a given attachment)
 bool FileInterner::getEnclosingUDI(const Rcl::Doc &doc, string& udi)
@@ -88,7 +101,7 @@ bool FileInterner::getEnclosingUDI(const Rcl::Doc &doc, string& udi)
         eipath.erase();
     }
     
-    make_udi(url_gpath(doc.idxurl.empty() ? doc.url : doc.idxurl), eipath, udi);
+    fileUdi::make_udi(url_gpath(doc.idxurl.empty() ? doc.url : doc.idxurl), eipath, udi);
     return true;
 }
 
@@ -148,7 +161,7 @@ void FileInterner::init(const string &f, const struct PathStat& stp,
     // manage some kind of cache.  Indexing by udi makes things easier
     // because they sometimes get a temp as actual input.
     string udi;
-    make_udi(f, cstr_null, udi);
+    fileUdi::make_udi(f, cstr_null, udi);
 
     cnf->setKeyDir(path_getfather(m_fn));
 
@@ -579,6 +592,7 @@ static void copymeta(const RclConfig *cfg, Rcl::Doc& doc, const RecollFilter* hp
             doc.addmeta(cfg->fieldCanon(entry.first), entry.second);
         }
     }
+    getKeyValue(hp->get_meta_data(), cstr_dj_keymd, doc.dmtime);
 }
 
 
@@ -922,6 +936,12 @@ breakloop:
         return FIError;
     }
 
+#ifdef DEBUGMETASTACK
+    for (const auto& h : m_handlers) {
+        dumpmap(std::cerr, h->get_meta_data());
+    }
+#endif // DEBUGMETASTACK
+    
     // Compute ipath and significant mimetype.  ipath is returned
     // through doc.ipath. We also retrieve some metadata fields from
     // the ancesters (like date or author). This is useful for email
@@ -945,8 +965,9 @@ breakloop:
         }
         docFieldsFromMetaCmds(m_cfg, m_cmdFields, doc);
     }
-    // Remove spurious commas from metadata values
+    // Remove spurious commas added by addmeta() from metadata values
     trimmeta(doc.meta);
+    trimstring(doc.dmtime, " ,");
 
     // Fix the bogus mtype used to force mh_text processing of text subdocs
     if (doc.mimetype == "text/plain1") {
