@@ -234,9 +234,9 @@ void ConfIndexW::initPanels()
 bool ConfIndexW::setupTopPanel(int idx)
 {
     m_w->addParam(idx, ConfTabsW::CFPT_DNL, "topdirs", 
-                  tr("Top directories"),
-                  tr("The list of directories where recursive "
-                     "indexing starts. Default: your home."));
+                  tr("Start folders"),
+                  tr("The list of folders/directories to be indexed. "
+                     "Sub-folders will be recursively processed. Default: your home."));
 
     ConfParamW *cparam = m_w->addParam(
         idx, ConfTabsW::CFPT_DNL, "skippedPaths", tr("Skipped paths"),
@@ -343,10 +343,8 @@ bool ConfIndexW::setupWebHistoryPanel(int idx)
     ConfParamW *cparam = m_w->addParam(
         idx, ConfTabsW::CFPT_FN, "webcachedir",
         tr("Web page store directory name"),
-        tr("The name for a directory where to store the copies "
-           "of visited web pages.<br>"
-           "A non-absolute path is taken relative to the "
-           "configuration directory."), 1);
+        tr("The name for a directory where to store the copies of visited web pages.<br>"
+           "A non-absolute path is taken relative to the configuration directory."), 1);
     m_w->enableLink(bparam, cparam);
 
     cparam = m_w->addParam(
@@ -354,8 +352,7 @@ bool ConfIndexW::setupWebHistoryPanel(int idx)
         tr("Entries will be recycled once the size is reached."
            "<br>"
            "Only increasing the size really makes sense because "
-           "reducing the value will not truncate an existing "
-           "file (only waste space at the end)."
+           "reducing the value will not truncate an existing file (only waste space at the end)."
             ), -1, 1000*1000); // Max 1TB...
     m_w->enableLink(bparam, cparam);
 
@@ -378,6 +375,15 @@ bool ConfIndexW::setupWebHistoryPanel(int idx)
     m_w->addBlurb(idx, tr("Note: old pages will be erased to make space for "
                           "new ones when the maximum size is reached. "
                           "Current size: %1").arg(u8s2qs(displayableBytes(sz))));
+
+    cparam = m_w->addParam(
+        idx, ConfTabsW::CFPT_FN, "webdownloadsdir",
+        tr("Browser add-on download folder"),
+        tr("Only set this if you set the \"Downloads subdirectory\" parameter in the Web browser "
+           "add-on settings. <br>In this case, it should be the full path to the directory "
+           "(e.g. /home/[me]/Downloads/my-subdir)"), 1);
+    m_w->enableLink(bparam, cparam);
+
     m_w->endOfList(idx);
     return true;
 }
@@ -439,14 +445,11 @@ ConfSubPanelW::ConfSubPanelW(QWidget *parent, ConfNull **config, RclConfig *rclc
         QObject::tr("The list of subdirectories in the indexed "
                     "hierarchy <br>where some parameters need "
                     "to be redefined. Default: empty."));
-    m_subdirs->getListBox()->setSelectionMode(
-        QAbstractItemView::SingleSelection);
+    m_subdirs->getListBox()->setSelectionMode(QAbstractItemView::SingleSelection);
     connect(m_subdirs->getListBox(), 
             SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)),
-            this, 
-            SLOT(subDirChanged(QListWidgetItem *, QListWidgetItem *)));
-    connect(m_subdirs, SIGNAL(entryDeleted(QString)),
-            this, SLOT(subDirDeleted(QString)));
+            this, SLOT(subDirChanged(QListWidgetItem *, QListWidgetItem *)));
+    connect(m_subdirs, SIGNAL(entryDeleted(QString)), this, SLOT(subDirDeleted(QString)));
 
     // We only retrieve the subkeys from the user's config (shallow),
     // no use to confuse the user by showing the subtrees which are
@@ -490,12 +493,10 @@ ConfSubPanelW::ConfSubPanelW(QWidget *parent, ConfNull **config, RclConfig *rclc
 
     ConfParamSLW *eskn = new ConfParamSLW(
         "skippedNames", m_groupbox, 
-        ConfLink(new ConfLinkPlusMinus(
-                     rclconf, config, "skippedNames",
-                     std::bind(&RclConfig::getSkippedNames, rclconf), &m_sk)),
+        ConfLink(new ConfLinkPlusMinus(rclconf, config, "skippedNames",
+                                       std::bind(&RclConfig::getSkippedNames, rclconf), &m_sk)),
         QObject::tr("Skipped names"),
-        QObject::tr("These are patterns for file or directory "
-                    " names which should not be indexed."));
+        QObject::tr("These are patterns for file or directory names which should not be indexed."));
     eskn->setFsEncoding(true);
     eskn->setImmediate();
     m_widgets.push_back(eskn);
