@@ -27,6 +27,12 @@
 #include "ecrontab.h"
 #include "smallut.h"
 #include "rclutil.h"
+#include "pathut.h"
+
+using std::string;
+using std::vector;
+using std::map;
+using std::list;
 
 static string marker;
 
