@@ -18,12 +18,6 @@
 #define _PREVIEW_W_H_INCLUDED_
 #include "autoconfig.h"
 
-// Always use a qtextbrowser for now, there is no compelling reason to
-// switch to webkit here
-#if 1 || defined(RESLIST_TEXTBROWSER)
-#define PREVIEW_TEXTBROWSER
-#endif
-
 #include <stdio.h>
 
 #include <memory>
@@ -32,22 +26,27 @@
 #include <QVariant>
 #include <QWidget>
 #include <QFont>
+#include <QImage>
 
-#ifdef PREVIEW_TEXTBROWSER
-#include <QTextBrowser>
-#define PREVIEW_PARENTCLASS QTextBrowser
+#if defined(USING_WEBENGINE) && !defined(PREVIEW_FORCETEXTBROWSER)
+#  include <QWebEngineView>
+#  define PREVIEW_PARENTCLASS QWebEngineView
+#  define PREVIEW_WEBENGINE
+#elif defined(USING_WEBKIT) && !defined(PREVIEW_FORCETEXTBROWSER)
+#  include <QWebView>
+#  define PREVIEW_PARENTCLASS QWebView
+#  define PREVIEW_WEBKIT
 #else
-#include <QtWebKit/QWebView>
-#define PREVIEW_PARENTCLASS QWebView
+#  include <QTextBrowser>
+#  define PREVIEW_PARENTCLASS QTextBrowser
+#  define PREVIEW_TEXTBROWSER
 #endif
-#include <qimage.h>
-
-#include "rcldb.h"
-#include "rclmain_w.h"
-#include "internfile.h"
 
 #include "ui_preview.h"
 
+#include "rcldoc.h"
+#include "hldata.h"
+#include "internfile.h"
 
 class QTabWidget;
 class QLabel;
@@ -62,6 +61,7 @@ class QTimer;
 class QEventLoop;
 class QProgressDialog;
 
+
 class PreviewTextEdit : public PREVIEW_PARENTCLASS {
     Q_OBJECT
 public:
@@ -78,7 +78,8 @@ public slots:
     void onAnchorClicked(const QUrl& url);
     void reloadAsPlainText();
     void reloadAsHTML();
-
+    void redisplay();
+    
     friend class Preview;
 protected:
     void mouseDoubleClickEvent(QMouseEvent *);
@@ -92,31 +93,31 @@ private:
     std::string m_ipath; // Internal doc path inside file
     int    m_docnum;  // Index of doc in db search results.
 
-    // doc out of internfile (previous fields come from the index) with
-    // main text erased (for space).
+    // doc out of internfile (previous fields come from the index) with main text erased (for
+    // space).
     Rcl::Doc m_fdoc; 
 
     // The input doc out of the index/query list
     Rcl::Doc m_dbdoc; 
 
-    // Saved rich (or plain actually) text: the textedit seems to
-    // sometimes (but not always) return its text stripped of tags, so
-    // this is needed (for printing for example)
+    // Saved rich (or plain actually) text: the textedit seems to sometimes (but not always) return
+    // its text stripped of tags, so this is needed (for printing for example)
     QString  m_richtxt;
     Qt::TextFormat m_format;
 
-    // Temporary file name (possibly, if displaying image). The
-    // TempFile itself is kept inside main.cpp (because that's where
-    // signal cleanup happens), but we use its name to ask for release
-    // when the tab is closed.
-    std::string m_tmpfilename;
+    // If displaying image, file name. This can be a temporary file. The TempFile itself is kept
+    // inside main.cpp (because that's where signal cleanup happens), but we use its name to ask for
+    // release when the tab is closed.
+    std::string m_imgfilename;
     QImage m_image;
-    DspType m_curdsp;
+
+    // What are we currently displaying: text/fields/image
+    DspType m_curdsp{PTE_DSPTXT};
 };
 
 class QShortcut;
 
-class Preview : public QDialog, public Ui::Preview {
+class Preview : public QWidget, public Ui::Preview {
     Q_OBJECT
 
 public:
@@ -149,8 +150,7 @@ public:
 public slots:
     // Search stuff
     virtual void searchTextChanged(const QString& text);
-    virtual void doSearch(const QString& str, bool next, bool reverse,
-                          bool wo = false);
+    virtual void doSearch(const QString& str, bool next, bool reverse, bool wo = false);
     virtual void nextPressed();
     virtual void prevPressed();
 
@@ -168,6 +168,7 @@ public slots:
     // Other
     virtual void zoomIn();
     virtual void zoomOut();
+    virtual void onUiPrefsChanged();
     
 signals:
     void previewClosed(Preview *);
@@ -207,8 +208,7 @@ private:
     virtual PreviewTextEdit *currentEditor();
     virtual PreviewTextEdit *addEditorTab();
     virtual bool loadDocInCurrentTab(const Rcl::Doc& idoc, int dnm);
-    void displayLoadError(
-        FileInterner::ErrorPossibleCause explain, bool canGetRawText);
+    void displayLoadError(FileInterner::ErrorPossibleCause explain, bool canGetRawText);
     bool runLoadThread(LoadThread& lthr, QTimer& tT, QEventLoop& loop,
                        QProgressDialog& progress, bool canGetRawText);
 };
