@@ -16,8 +16,6 @@
  */
 #include "autoconfig.h"
 
-#include "safesysstat.h"
-
 #include <string>
 #include <algorithm>
 #include <list>
@@ -180,6 +178,9 @@ void UIPrefsDialog::setFromPrefs()
     autoSpellMaxDistSB->setEnabled(prefs.autoSpell);
     showcompleterhitcountsCB->setChecked(prefs.showcompleterhitcounts);
     ssearchCompleterHistCntSB->setValue(prefs.ssearchCompleterHistCnt);
+    sidefilterdateformatLE->setText(prefs.sidefilterdateformat);
+    ignwildsCB->setChecked(prefs.ignwilds);
+    pvmaxfldlenSB->setValue(prefs.pvmaxfldlen);
     /*INSERTHERE_LOAD*/
 
     // See qxtconfirmationmessage. Needs to be -1 for the dialog to show.
@@ -461,6 +462,9 @@ void UIPrefsDialog::accept()
     prefs.autoSpellMaxDist = autoSpellMaxDistSB->value();
     prefs.showcompleterhitcounts = showcompleterhitcountsCB->isChecked();
     prefs.ssearchCompleterHistCnt = ssearchCompleterHistCntSB->value();
+    prefs.sidefilterdateformat = sidefilterdateformatLE->text();
+    prefs.ignwilds = ignwildsCB->isChecked();
+    prefs.pvmaxfldlen = pvmaxfldlenSB->value();
     /*INSERTHERE_ACCEPT*/
 
     // -1 is the qxtconf... predefined value to show the dialog
