@@ -74,7 +74,7 @@ std::string make_abstract(Rcl::Doc& doc, Rcl::Query& query, bool asSnippets,
     std::vector<Rcl::Snippet> snippets;
     std::ostringstream str;
     int cnt = 0;
-    if (query.makeDocAbstract(doc, &g_hiliter, snippets, 0, -1, true)) {
+    if (query.makeDocAbstract(doc, &g_hiliter, snippets, asSnippets?snipcount:0, -1, true)) {
         for (const auto& snippet : snippets) {
             if (snipcount > 0 && ++cnt > snipcount)
                 break;
@@ -105,9 +105,7 @@ void output_fields(std::vector<std::string> fields, Rcl::Doc& doc,
         if (fld == "abstract") {
             base64_encode(make_abstract(doc, query, asSnippets, snipcnt, showlines, hldata), out);
         } else if (fld == "xdocid") {
-            char cdocid[30];
-            sprintf(cdocid, "%lu", (unsigned long)doc.xdocid);
-            base64_encode(cdocid, out);
+            base64_encode(std::to_string(doc.xdocid), out);
         } else {
             base64_encode(doc.meta[fld], out);
         }
@@ -484,8 +482,6 @@ int recollq(RclConfig **cfp, int argc, char **argv)
                 titleorfn = path_getsimple(url);
             }
 
-            char cpc[20];
-            sprintf(cpc, "%d", doc.pc);
             cout
                 << doc.mimetype << "\t"
                 << "[" << doc.url << "]" << "\t" 
