@@ -32,6 +32,7 @@
 #include "pathut.h"
 #include "rcldoc.h"
 #include "syngroups.h"
+#include "fileudi.h"
 
 using namespace std;
 
@@ -108,7 +109,11 @@ bool Db::getAllDbMimeTypes(std::vector<std::string>& exp)
         return false;
     }
     for (const auto& entry : res.entries) {
-        exp.push_back(Rcl::strip_prefix(entry.term));
+        // Eliminate some garbage types. Happens;
+        auto tp = Rcl::strip_prefix(entry.term);
+        if (tp.find('/') == std::string::npos)
+            continue;
+        exp.push_back(tp);
     }
     return true;
 }
@@ -584,6 +589,16 @@ bool Db::dirlist(int depth, std::string& root, std::vector<std::string>& dirs)
                 auto pos = ixterm.find_first_of('|');
                 if (pos < ixterm.size() - 1)
                     continue;
+
+                // Have to check for a hashed UDI, and fetch the data record and its URL then.
+                if ((int)ixterm.size() == fileUdi::hashed_udi_size()) {
+                    Rcl::Doc doc;
+                    if (!getDoc(ixterm, -1, doc, false) || doc.pc == -1) {
+                        continue;
+                    }
+                    ixterm = fileurltolocalpath(doc.url);
+                }
+
                 listall.push_back(ixterm);
             }
             break;
