@@ -20,26 +20,36 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include "safefcntl.h"
+#include <fcntl.h>
 #include "safeunistd.h"
 #include "cstr.h"
 #include "execmd.h"
 #include "fstreewalk.h"
 
 #ifdef _WIN32
-#include "safewindows.h"
+
+#ifndef NOMINMAX
+# define NOMINMAX
+#endif
+#define WIN32_LEAN_AND_MEAN
+#define NOGDI
+#include <windows.h>
 #include <Shlobj.h>
-#else
+
+#else // _WIN32
+
 #include <sys/param.h>
 #include <pwd.h>
 #include <sys/file.h>
-#endif
+
+#endif // !_WIN32
+
 #ifdef __APPLE__
 #include <mach-o/dyld.h>
 #endif
+
 #include <errno.h>
 #include <sys/types.h>
-#include "safesysstat.h"
 
 #include <mutex>
 #include <map>
@@ -98,7 +108,7 @@ template <class T> void addmeta(T& store, const string& nm, const string& value)
     }
     std::string& pval = it->second;
     if (pval.empty()) {
-        maybecommas(pval , value);
+        maybecommas(pval, value);
     } else {
         std::string nval;
         maybecommas(nval, value);
@@ -115,7 +125,12 @@ template <class T> void addmeta(T& store, const string& nm, const string& value)
 template <class T> void trimmeta(T& store)
 {
     for (auto& [_,value] : store) {
-        trimstring(value, " ,");
+        if (value.empty())
+            continue;
+        if (value.back() == ',')
+            value.pop_back();
+        if (!value.empty() && value[0] == ',')
+            value.erase(0, 1);
     }
 }
 template void addmeta<map<string, string>>(map<string, string>&, const string&, const string&);
@@ -283,7 +298,7 @@ const string& path_pkgdatadir()
         "c:/program files/recoll"};
     for (const auto& path : paths) {
         datadir = path_cat(path, "Share");
-        if (path_exists(datadir)) {
+        if (path_exists(path_cat(datadir, {"examples", "recoll.conf"}))) {
             return datadir;
         }
     }
@@ -589,7 +604,7 @@ bool maketmpdir(string& tdir, string& reason)
     // mkdtemp
 
 #if !defined(HAVE_MKDTEMP) || defined(_WIN32)
-    if (mkdir(tdir.c_str(), 0700) < 0) {
+    if (!path_makepath(tdir, 0700)) {
         reason = string("maketmpdir: mkdir ") + tdir + " failed";
         tdir.erase();
         return false;
