@@ -23,7 +23,7 @@
 #include <map>
 #include <string>
 #include <memory>
-
+#include <vector>
 
 extern void rclutil_init_mt();
 
@@ -38,14 +38,13 @@ extern std::string path_homedata();
 /// e.g. /usr/share/recoll. Depends on OS and config
 extern const std::string& path_pkgdatadir();
 
-#ifdef _WIN32
-extern std::string path_thisexecpath();
-#endif
+/// Encode the path in a manner compatible to freedesktop thumbnail path computation. In addition to
+/// some printable punctuation (SPC"#%;<>?[\]^`{|}), this will also encode unprintable characters
+/// (control or 8 bit set), so it can be used as a general unprintable data encoder. This is
+/// absolutely not a general URL processor though as it will happily trash query and fragment.
+extern std::string path_pcencode(const std::string& url, std::string::size_type offs = 0);
 
-/// Encode according to rfc 1738
-extern std::string url_encode(const std::string& url, std::string::size_type offs = 0);
-//// Convert to file path if url is like file://. This modifies the
-//// input (and returns a copy for convenience)
+//// Convert to file path if url is like file://. Else returns empty string.
 extern std::string fileurltolocalpath(std::string url);
 /// Test for file:/// url
 extern bool urlisfileurl(const std::string& url);
@@ -58,8 +57,7 @@ extern std::string url_gpath(const std::string& url);
 extern std::string path_pathtofileurl(const std::string& path);
 
 /// Transcode to utf-8 if possible or url encoding, for display.
-extern bool printableUrl(const std::string& fcharset,
-                         const std::string& in, std::string& out);
+extern bool printableUrl(const std::string& fcharset, const std::string& in, std::string& out);
 /// Same but, in the case of a Windows local path, also turn "c:/" into
 /// "/c/" This should be used only for splitting the path in rcldb.
 #ifdef _WIN32
@@ -67,6 +65,8 @@ extern std::string path_slashdrive(const std::string& path);
 #endif
 extern std::string url_gpathS(const std::string& url);
 
+bool path_samepath(const std::string& p1, const std::string& p2);
+
 /// Like strftime but guaranteed utf-8 output (esp. useful on Windows)
 struct tm;
 extern std::string utf8datestring(const std::string& format, struct tm *tm);
@@ -132,8 +132,10 @@ extern bool thumbPathForUrl(const std::string& url, int size, std::string& path)
 // string data (to pass to other thread):
 template <class T> void map_ss_cp_noshr(T s, T *d);
 
-// Set or extend metadata field. We store the data as CSV
+// Set or extend metadata field. We store the data as almost CSV
 template <class T> void addmeta(T& store, const std::string& nm, const std::string& value);
+// Remove some commas at the end
+template <class T> void trimmeta(T& store);
 
 // Compare charset names, removing the more common spelling variations
 extern bool samecharset(const std::string& cs1, const std::string& cs2);
@@ -148,4 +150,30 @@ extern int u8DLDistance(const std::string& str1, const std::string str2);
 // "file -i" output after the path has been removed). Exported here so that it can be unit-tested.
 extern std::string growmimearoundslash(std::string mime);
 
+// Parse date interval specifier into pair of y,m,d dates.  The format
+// for the time interval is based on a subset of iso 8601 with
+// the addition of open intervals, and removal of all time indications.
+// 'P' is the Period indicator, it's followed by a length in
+// years/months/days (or any subset thereof)
+// Dates: YYYY-MM-DD YYYY-MM YYYY
+// Periods: P[nY][nM][nD] where n is an integer value.
+// At least one of YMD must be specified
+// The separator for the interval is /. Interval examples
+// YYYY/ (from YYYY) YYYY-MM-DD/P3Y (3 years after date) etc.
+// This returns a pair of y,m,d dates.
+struct DateInterval {
+    int y1;
+    int m1;
+    int d1;
+    int y2;
+    int m2;
+    int d2;
+};
+extern bool parsedateinterval(const std::string& s, DateInterval *di);
+extern int monthdays(int mon, int year);
+
+// Try to find a list of recoll configuration directories under $HOME. Heuristic. where defaults to
+// home.
+extern std::vector<std::string> guess_recoll_confdirs(const std::string& where = "");
+
 #endif /* _RCLUTIL_H_INCLUDED_ */
